Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2927)

Unified Diff: chrome/browser/chrome_content_browser_client.cc

Issue 961443002: Three way experiment for "Show saved copy" button. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Patched in CL 952563003 Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/about_flags.cc ('k') | chrome/browser/errorpage_browsertest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chrome_content_browser_client.cc
diff --git a/chrome/browser/chrome_content_browser_client.cc b/chrome/browser/chrome_content_browser_client.cc
index d3e8e0d53116cdbc0d0945946929898bfcae7d4e..34a38391a8b466ee7ac8f54f824a5ac01d821619 100644
--- a/chrome/browser/chrome_content_browser_client.cc
+++ b/chrome/browser/chrome_content_browser_client.cc
@@ -1408,24 +1408,29 @@ void ChromeContentBrowserClient::AppendExtraCommandLineSwitches(
}
{
// Enable load stale cache if this session is in the field trial or
// the user explicitly enabled it. Note that as far as the renderer
// is concerned, the feature is enabled if-and-only-if the
// kEnableOfflineLoadStaleCache flag is on the command line;
// the yes/no/default behavior is only at the browser command line
// level.
// Command line switches override
if (browser_command_line.HasSwitch(
- switches::kEnableOfflineLoadStaleCache)) {
- command_line->AppendSwitch(switches::kEnableOfflineLoadStaleCache);
+ switches::kEnableShowSavedCopyPrimary)) {
mmenke 2015/02/27 20:27:14 Maybe switch to a single switch with 3 different v
megjablon 2015/02/27 22:41:57 I changed it to a single switch with 3 values. I c
+ command_line->AppendSwitch(switches::kEnableShowSavedCopyPrimary);
+ } else if (browser_command_line.HasSwitch(
+ switches::kEnableShowSavedCopySecondary)) {
+ command_line->AppendSwitch(switches::kEnableShowSavedCopySecondary);
} else if (!browser_command_line.HasSwitch(
- switches::kDisableOfflineLoadStaleCache)) {
+ switches::kDisableShowSavedCopy)) {
std::string group =
base::FieldTrialList::FindFullName("LoadStaleCacheExperiment");
- if (group == "Enabled")
- command_line->AppendSwitch(switches::kEnableOfflineLoadStaleCache);
+ if (group == "Primary")
+ command_line->AppendSwitch(switches::kEnableShowSavedCopyPrimary);
+ else if (group == "Secondary")
+ command_line->AppendSwitch(switches::kEnableShowSavedCopySecondary);
}
}
« no previous file with comments | « chrome/browser/about_flags.cc ('k') | chrome/browser/errorpage_browsertest.cc » ('j') | no next file with comments »
@@ -1408,24 +1408,29 @@ void ChromeContentBrowserClient::AppendExtraCommandLineSwitches(
}
{
- // Enable load stale cache if this session is in the field trial or
- // the user explicitly enabled it. Note that as far as the renderer
- // is concerned, the feature is enabled if-and-only-if the
- // kEnableOfflineLoadStaleCache flag is on the command line;
- // the yes/no/default behavior is only at the browser command line
- // level.
+ // Enable showing a saved copy if this session is in the field trial
+ // or the user explicitly enabled it. Note that as far as the
+ // renderer is concerned, the feature is enabled if-and-only-if
+ // one of the kEnableShowSavedCopy* switches is on the command
+ // line; the yes/no/default behavior is only at the browser
+ // command line level.
// Command line switches override
if (browser_command_line.HasSwitch(

Powered by Google App Engine
This is Rietveld 408576698